
#ifndef VTKPVVTKEXTENSIONSIOENSIGHT_EXPORT_H
#define VTKPVVTKEXTENSIONSIOENSIGHT_EXPORT_H

#ifdef VTKPVVTKEXTENSIONSIOENSIGHT_STATIC_DEFINE
#  define VTKPVVTKEXTENSIONSIOENSIGHT_EXPORT
#  define VTKPVVTKEXTENSIONSIOENSIGHT_NO_EXPORT
#else
#  ifndef VTKPVVTKEXTENSIONSIOENSIGHT_EXPORT
#    ifdef VTKExtensionsIOEnSight_EXPORTS
        /* We are building this library */
#      define VTKPVVTKEXTENSIONSIOENSIGHT_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define VTKPVVTKEXTENSIONSIOENSIGHT_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef VTKPVVTKEXTENSIONSIOENSIGHT_NO_EXPORT
#    define VTKPVVTKEXTENSIONSIOENSIGHT_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef VTKPVVTKEXTENSIONSIOENSIGHT_DEPRECATED
#  define VTKPVVTKEXTENSIONSIOENSIGHT_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef VTKPVVTKEXTENSIONSIOENSIGHT_DEPRECATED_EXPORT
#  define VTKPVVTKEXTENSIONSIOENSIGHT_DEPRECATED_EXPORT VTKPVVTKEXTENSIONSIOENSIGHT_EXPORT VTKPVVTKEXTENSIONSIOENSIGHT_DEPRECATED
#endif

#ifndef VTKPVVTKEXTENSIONSIOENSIGHT_DEPRECATED_NO_EXPORT
#  define VTKPVVTKEXTENSIONSIOENSIGHT_DEPRECATED_NO_EXPORT VTKPVVTKEXTENSIONSIOENSIGHT_NO_EXPORT VTKPVVTKEXTENSIONSIOENSIGHT_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef VTKPVVTKEXTENSIONSIOENSIGHT_NO_DEPRECATED
#    define VTKPVVTKEXTENSIONSIOENSIGHT_NO_DEPRECATED
#  endif
#endif

/* VTK-HeaderTest-Exclude: vtkPVVTKExtensionsIOEnSightModule.h */

/* Include ABI Namespace */
#include "vtkABINamespace.h"

#endif /* VTKPVVTKEXTENSIONSIOENSIGHT_EXPORT_H */
